@@ -8,7 +8,7 @@ use overload
  '""'     => \&asString,
  fallback => 1;
 
-$VERSION = '0.11';
+$VERSION = '0.12';
 @EXPORT_OK   = qw(AUTOLOAD);
 %EXPORT_TAGS = ( 'standard' => [qw(AUTOLOAD)] );
 
@@ -21,6 +21,9 @@ sub new {
 
 sub AUTOLOAD {
   my ($pack,$func) = $AUTOLOAD =~ /(.+)::([^:]+)$/;
+
+  $func =~ s/__/::/g;
+
   my $req = "CGI::Widget::$func";
   eval "require $req" || die "couldn't find $req : $!";
   return $req->new(@_);
@@ -66,11 +69,15 @@ Widgets can be accessed either by explicitly creating Widget objects, as:
 
 or by using the CGI::Widget standard import tag, as:
   use CGI::Widget qw(:standard);
-  print Series(),"\n";
+  print Series(),"\n";    #constructs CGI::Widget::Series
+  print HList__Node,"\n"; #constructs CGI::Widget::HList::Node
 
-Using ':standard' uses an AUTOLOAD subroutine to check for Widget classes
-in the CGI::Widget namespace.  If someone knows of a better way to do
-this, let me know!
+Using ':standard' uses an AUTOLOAD subroutine that tries to construct
+an object for you that resides under CGI::Widget.  For subclasses
+of CGI::Widget subclasses and subclasses thereof, a double underscore
+(__) must be given in place of the normal double colon (::) used to
+delimit package names.  If someone knows a better way to do this, let
+me know!
 
 =head2 EXPORT
 
