@@ -3,4 +3,6 @@ use lib '../blib/lib';
 use strict;
 use CGI::Widget ":standard";
 
-print Series(-length=>10,-render=>sub{return "asdf".shift});
+
+print ref HList__Node();
+#print Series(-length=>10,-render=>sub{return "asdf".shift});
